@@ -8,13 +8,21 @@
 TodoItemTreeWidget::TodoItemTreeWidget(QWidget *parent) : QTreeWidget(parent) { Q_UNUSED(parent); }
 
 void TodoItemTreeWidget::dropEvent(QDropEvent *e) {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    QModelIndex droppedIndex = indexAt(e->position().toPoint());
+#else
     QModelIndex droppedIndex = indexAt(e->pos());
+#endif
 
     if (!droppedIndex.isValid()) {
         return;
     }
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    auto destItem = itemAt(e->position().toPoint());
+#else
     auto destItem = itemAt(e->pos());
+#endif
     auto destUid = destItem->data(0, Qt::UserRole).toString();
 
     qDebug() << __func__ << " - 'destUid': " << destUid;
